@@ -11,7 +11,7 @@ except ImportError:
     dbus = False
 
 from mopidy import core
-from mopidy.backends import dummy
+from mopidy.backend import dummy
 from mopidy.core import PlaybackState
 from mopidy.models import Album, Artist, Track
 
@@ -806,8 +806,8 @@ class PlayerInterfaceTest(unittest.TestCase):
         self.assertEqual(self.core.playback.state.get(), PLAYING)
         self.assertEqual(self.core.playback.current_track.get().uri, 'dummy:a')
 
-    def test_open_uri_is_ignored_if_can_play_is_false(self):
-        self.mpris.get_CanPlay = lambda *_: False
+    def test_open_uri_is_ignored_if_can_control_is_false(self):
+        self.mpris.get_CanControl = lambda *_: False
         self.backend.library.dummy_library = [
             Track(uri='dummy:/test/uri')]
         self.mpris.OpenUri('dummy:/test/uri')
@@ -815,20 +815,17 @@ class PlayerInterfaceTest(unittest.TestCase):
 
     def test_open_uri_ignores_uris_with_unknown_uri_scheme(self):
         self.assertListEqual(self.core.uri_schemes.get(), ['dummy'])
-        self.mpris.get_CanPlay = lambda *_: True
         self.backend.library.dummy_library = [Track(uri='notdummy:/test/uri')]
         self.mpris.OpenUri('notdummy:/test/uri')
         self.assertEqual(len(self.core.tracklist.tracks.get()), 0)
 
     def test_open_uri_adds_uri_to_tracklist(self):
-        self.mpris.get_CanPlay = lambda *_: True
         self.backend.library.dummy_library = [Track(uri='dummy:/test/uri')]
         self.mpris.OpenUri('dummy:/test/uri')
         self.assertEqual(
             self.core.tracklist.tracks.get()[0].uri, 'dummy:/test/uri')
 
     def test_open_uri_starts_playback_of_new_track_if_stopped(self):
-        self.mpris.get_CanPlay = lambda *_: True
         self.backend.library.dummy_library = [Track(uri='dummy:/test/uri')]
         self.core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
         self.assertEqual(self.core.playback.state.get(), STOPPED)
@@ -840,7 +837,6 @@ class PlayerInterfaceTest(unittest.TestCase):
             self.core.playback.current_track.get().uri, 'dummy:/test/uri')
 
     def test_open_uri_starts_playback_of_new_track_if_paused(self):
-        self.mpris.get_CanPlay = lambda *_: True
         self.backend.library.dummy_library = [Track(uri='dummy:/test/uri')]
         self.core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
         self.core.playback.play()
@@ -855,7 +851,6 @@ class PlayerInterfaceTest(unittest.TestCase):
             self.core.playback.current_track.get().uri, 'dummy:/test/uri')
 
     def test_open_uri_starts_playback_of_new_track_if_playing(self):
-        self.mpris.get_CanPlay = lambda *_: True
         self.backend.library.dummy_library = [Track(uri='dummy:/test/uri')]
         self.core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
         self.core.playback.play()
